
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.22.0rc2',
    'branch_nick': 'feature-0-Release__1_22_0rc2_preparation',
    'revision_id': '7832e2bfd02709405ca99c8b34a6d6f5048b57f1',
    'revno': 9340
}
